@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- * $Id: battstat-hal.c,v 1.4 2005/08/02 02:17:35 ryanl Exp $
+ * $Id: battstat-hal.c,v 1.5 2005/12/04 08:18:49 ryanl Exp $
  */
 
 #include <config.h>
@@ -105,7 +105,7 @@ adaptor_update_property( LibHalContext *ctx, struct adaptor_info *adaptor,
 
   dbus_error_init( &error );
 
-  if( !strcmp( key, "ac_adaptor.present" ) )
+  if( !strcmp( key, "ac_adapter.present" ) )
     adaptor->present =
       libhal_device_get_property_bool( ctx, adaptor->udi, key, &error );
 
