@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.16 2005/06/09 08:42:59 kmaraas Exp $ */
+/* $Id: main.c,v 1.20 2006/01/10 01:36:17 kmaraas Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -15,6 +15,9 @@
 #include <gnome.h>
 #include <panel-applet.h>
 
+#include <libgweather/gweather-gconf.h>
+#include <libgweather/gweather-prefs.h>
+
 #include "gweather.h"
 #include "gweather-pref.h"
 #include "gweather-dialog.h"
@@ -26,15 +29,19 @@ gweather_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 {
 	GWeatherApplet *gw_applet;
 
+	char *prefs_key = panel_applet_get_preferences_key(applet);
+
 	panel_applet_add_preferences(applet, "/schemas/apps/gweather/prefs", NULL);
 	
 	gw_applet = g_new0(GWeatherApplet, 1);   
 	
 	gw_applet->applet = applet;
 	gw_applet->gweather_info = NULL;
+	gw_applet->gconf = gweather_gconf_new(prefs_key);
+	g_free (prefs_key);
     	gweather_applet_create(gw_applet);
 
-    	gweather_pref_load(gw_applet);
+    	gweather_prefs_load(&gw_applet->gweather_pref, gw_applet->gconf);
     
     	gweather_update(gw_applet);
 
